==> xlr-application-pipelines-module-23.1.0-rc.2-sources.jar: web/include/applications-management/ducks/managed-application.reducer.spec.ts <==
import { applicationManagement, initialState } from './managed-application.reducer';
import { APPLICATION_MANAGEMENT_SLICE_NAME } from '../constants';

describe('managed application reducer', () => {
    const {
        setTemplates,
        fetchTemplates,
        setPage,
        loadManagedApplications,
        setIsLoading,
        setManagedApplications,
        setManagedApplicationsCount,
        storeFilters,
        getFilters,
        createRelease,
    } = applicationManagement.actions;

    it('should have the initial state', () => {
        expect(applicationManagement.name).toBe(APPLICATION_MANAGEMENT_SLICE_NAME);
        expect(applicationManagement.reducer(undefined, { type: 'default' })).toBe(initialState);
        expect(Object.keys(applicationManagement.actions)).toStrictEqual([
            'setTemplates',
            'fetchTemplates',
            'setPage',
            'loadManagedApplications',
            'setIsLoading',
            'setManagedApplications',
            'setManagedApplicationsCount',
            'storeFilters',
            'getFilters',
            'createRelease',
        ]);
    });

    describe('reducers', () => {
        describe('setTemplates', () => {
            it('should set templates', () => {
                const template = { id: 'template-1', title: 'title-1', description: 'description-1' } as never;
                const state = applicationManagement.reducer(initialState, setTemplates([template]));
                expect(state.templates.length).toBe(1);
                expect(state.templates).toStrictEqual([template]);
                expect(state.templates).toContain(template);
            });
        });
        describe('fetchTemplates', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, fetchTemplates({ parentId: 'folder-1' }));
                expect(state).toStrictEqual(initialState);
            });
        });
        describe('setPage', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setPage('page' as never));
                expect(state.page).toStrictEqual('page');
            });
        });
        describe('loadManagedApplications', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, loadManagedApplications());
                expect(state).toStrictEqual(initialState);
            });
        });
        describe('setIsLoading', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setIsLoading(true));
                expect(state.isLoading).toBe(true);
            });
        });
        describe('setManagedApplications', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setManagedApplications([1] as never));
                expect(state.managedApplications).toStrictEqual([1]);
            });
        });
        describe('setManagedApplicationsCount', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setManagedApplicationsCount(2));
                expect(state.count).toBe(2);
            });
        });
        describe('storeFilters', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, storeFilters());
                expect(state).toStrictEqual(initialState);
            });
        });
        describe('getFilters', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, getFilters('folderId'));
                expect(state.page.folderId).toBe('folderId');
            });
        });
        describe('createRelease', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, createRelease({} as never));
                expect(state).toStrictEqual(initialState);
            });
        });
    });
});

==> xlr-application-pipelines-module-23.3.9-sources.jar: web/include/applications-management/ducks/managed-application.reducer.spec.ts <==
import { applicationManagement, initialState } from './managed-application.reducer';
import { APPLICATION_MANAGEMENT_SLICE_NAME } from '../constants';

describe('managed application reducer', () => {
    const {
        setPage,
        loadManagedApplications,
        navigateToWorkflow,
        setIsLoading,
        setManagedApplications,
        setManagedApplicationsCount,
        storeFilters,
        getFilters,
        createManagedApplicationsFromWebhookSource,
        setCondition,
        setManagedApplicationsTotalCount,
    } = applicationManagement.actions;
    it('should have the initial state', () => {
        expect(applicationManagement.name).toBe(APPLICATION_MANAGEMENT_SLICE_NAME);
        expect(applicationManagement.reducer(undefined, { type: 'default' })).toBe(initialState);
        expect(Object.keys(applicationManagement.actions)).toStrictEqual([
            'setPage',
            'loadManagedApplications',
            'navigateToWorkflow',
            'setCondition',
            'setIsLoading',
            'setManagedApplications',
            'setManagedApplicationsCount',
            'setManagedApplicationsTotalCount',
            'storeFilters',
            'getFilters',
            'createManagedApplicationsFromWebhookSource',
        ]);
    });

    describe('reducers', () => {
        describe('setPage', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setPage('page' as never));
                expect(state.page).toStrictEqual('page');
            });
        });
        describe('loadManagedApplications', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, loadManagedApplications());
                expect(state).toStrictEqual(initialState);
            });
        });
        describe('setCondition', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setCondition('app'));
                expect(state.condition).toStrictEqual('app');
            });
        });
        describe('setIsLoading', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setIsLoading(true));
                expect(state.isLoading).toBe(true);
            });
        });
        describe('setManagedApplications', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setManagedApplications([1] as never));
                expect(state.managedApplications).toStrictEqual([1]);
            });
        });
        describe('setManagedApplicationsCount', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setManagedApplicationsCount(2));
                expect(state.count).toBe(2);
            });
        });
        describe('setManagedApplicationsTotalCount', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, setManagedApplicationsTotalCount(2));
                expect(state.totalCount).toBe(2);
            });
        });
        describe('storeFilters', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, storeFilters());
                expect(state).toStrictEqual(initialState);
            });
        });
        describe('getFilters', () => {
            it('should update state', () => {
                const state = applicationManagement.reducer(initialState, getFilters('folderId'));
                expect(state.page.folderId).toBe('folderId');
            });
        });
        describe('createManagedApplicationsFromWebhookSource', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, createManagedApplicationsFromWebhookSource('webhookSourceId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('navigateToWorkflow', () => {
            it('should not update state', () => {
                const state = applicationManagement.reducer(initialState, navigateToWorkflow({ actionName: 'some', managedApplicationId: 'id' }));
                expect(state).toStrictEqual(initialState);
            });
        });
    });
});
